@@ -117,11 +117,12 @@ class FireServiceRotaOAuth():
          return parsed_response
 
 
-      def refresh_access_token(self, token_info):
+      def refresh_access_token(self, token_info, force=False):
          """Refresh access token if expired."""
          if token_info is None:
                return token_info
-         if not self.is_token_expired(token_info):
+         if not force:
+            if not self.is_token_expired(token_info):
                return token_info
 
          try:         
